@@ -13,7 +13,7 @@ Usage::
     ```
 """
 import sys
-from typing import Any, Dict, Type, overload
+from typing import Any, Dict, Mapping, Type, overload
 
 from botocore.client import BaseClient, ClientMeta
 
@@ -73,7 +73,7 @@ __all__ = ("SnowballClient",)
 class BotocoreClientError(BaseException):
     MSG_TEMPLATE: str
 
-    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+    def __init__(self, error_response: Mapping[str, Any], operation_name: str) -> None:
         self.response: Dict[str, Any]
         self.operation_name: str
 
@@ -95,7 +95,7 @@ class Exceptions:
 
 class SnowballClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/snowball.html#Snowball.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/snowball.html#Snowball.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_snowball/client.html)
     """
 
@@ -111,7 +111,7 @@ class SnowballClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/snowball.html#Snowball.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/snowball.html#Snowball.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_snowball/client.html#can_paginate)
         """
 
@@ -119,7 +119,7 @@ class SnowballClient(BaseClient):
         """
         Cancels a cluster job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/snowball.html#Snowball.Client.cancel_cluster)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/snowball.html#Snowball.Client.cancel_cluster)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_snowball/client.html#cancel_cluster)
         """
 
@@ -127,7 +127,7 @@ class SnowballClient(BaseClient):
         """
         Cancels the specified job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/snowball.html#Snowball.Client.cancel_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/snowball.html#Snowball.Client.cancel_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_snowball/client.html#cancel_job)
         """
 
@@ -135,7 +135,7 @@ class SnowballClient(BaseClient):
         """
         Creates an address for a Snow device to be shipped to.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/snowball.html#Snowball.Client.create_address)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/snowball.html#Snowball.Client.create_address)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_snowball/client.html#create_address)
         """
 
@@ -159,7 +159,7 @@ class SnowballClient(BaseClient):
         """
         Creates an empty cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/snowball.html#Snowball.Client.create_cluster)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/snowball.html#Snowball.Client.create_cluster)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_snowball/client.html#create_cluster)
         """
 
@@ -188,7 +188,7 @@ class SnowballClient(BaseClient):
         Creates a job to import or export data between Amazon S3 and your on-premises
         data center.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/snowball.html#Snowball.Client.create_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/snowball.html#Snowball.Client.create_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_snowball/client.html#create_job)
         """
 
@@ -202,7 +202,7 @@ class SnowballClient(BaseClient):
         """
         Creates a job with the long-term usage option for a device.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/snowball.html#Snowball.Client.create_long_term_pricing)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/snowball.html#Snowball.Client.create_long_term_pricing)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_snowball/client.html#create_long_term_pricing)
         """
 
@@ -212,7 +212,7 @@ class SnowballClient(BaseClient):
         """
         Creates a shipping label that will be used to return the Snow device to AWS.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/snowball.html#Snowball.Client.create_return_shipping_label)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/snowball.html#Snowball.Client.create_return_shipping_label)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_snowball/client.html#create_return_shipping_label)
         """
 
@@ -221,7 +221,7 @@ class SnowballClient(BaseClient):
         Takes an `AddressId` and returns specific details about that address in the form
         of an `Address` object.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/snowball.html#Snowball.Client.describe_address)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/snowball.html#Snowball.Client.describe_address)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_snowball/client.html#describe_address)
         """
 
@@ -231,7 +231,7 @@ class SnowballClient(BaseClient):
         """
         Returns a specified number of `ADDRESS` objects.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/snowball.html#Snowball.Client.describe_addresses)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/snowball.html#Snowball.Client.describe_addresses)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_snowball/client.html#describe_addresses)
         """
 
@@ -240,7 +240,7 @@ class SnowballClient(BaseClient):
         Returns information about a specific cluster including shipping information,
         cluster status, and other important metadata.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/snowball.html#Snowball.Client.describe_cluster)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/snowball.html#Snowball.Client.describe_cluster)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_snowball/client.html#describe_cluster)
         """
 
@@ -249,7 +249,7 @@ class SnowballClient(BaseClient):
         Returns information about a specific job including shipping information, job
         status, and other important metadata.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/snowball.html#Snowball.Client.describe_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/snowball.html#Snowball.Client.describe_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_snowball/client.html#describe_job)
         """
 
@@ -260,21 +260,21 @@ class SnowballClient(BaseClient):
         Information on the shipping label of a Snow device that is being returned to
         AWS.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/snowball.html#Snowball.Client.describe_return_shipping_label)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/snowball.html#Snowball.Client.describe_return_shipping_label)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_snowball/client.html#describe_return_shipping_label)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Dict[str, Any] = None,
+        Params: Mapping[str, Any] = None,
         ExpiresIn: int = 3600,
         HttpMethod: str = None,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/snowball.html#Snowball.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/snowball.html#Snowball.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_snowball/client.html#generate_presigned_url)
         """
 
@@ -283,7 +283,7 @@ class SnowballClient(BaseClient):
         Returns a link to an Amazon S3 presigned URL for the manifest file associated
         with the specified `JobId` value.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/snowball.html#Snowball.Client.get_job_manifest)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/snowball.html#Snowball.Client.get_job_manifest)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_snowball/client.html#get_job_manifest)
         """
 
@@ -291,7 +291,7 @@ class SnowballClient(BaseClient):
         """
         Returns the `UnlockCode` code value for the specified job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/snowball.html#Snowball.Client.get_job_unlock_code)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/snowball.html#Snowball.Client.get_job_unlock_code)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_snowball/client.html#get_job_unlock_code)
         """
 
@@ -300,7 +300,7 @@ class SnowballClient(BaseClient):
         Returns information about the Snow Family service limit for your account, and
         also the number of Snow devices your account has in use.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/snowball.html#Snowball.Client.get_snowball_usage)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/snowball.html#Snowball.Client.get_snowball_usage)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_snowball/client.html#get_snowball_usage)
         """
 
@@ -309,7 +309,7 @@ class SnowballClient(BaseClient):
         Returns an Amazon S3 presigned URL for an update file associated with a
         specified `JobId` .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/snowball.html#Snowball.Client.get_software_updates)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/snowball.html#Snowball.Client.get_software_updates)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_snowball/client.html#get_software_updates)
         """
 
@@ -319,7 +319,7 @@ class SnowballClient(BaseClient):
         """
         Returns an array of `JobListEntry` objects of the specified length.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/snowball.html#Snowball.Client.list_cluster_jobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/snowball.html#Snowball.Client.list_cluster_jobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_snowball/client.html#list_cluster_jobs)
         """
 
@@ -329,7 +329,7 @@ class SnowballClient(BaseClient):
         """
         Returns an array of `ClusterListEntry` objects of the specified length.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/snowball.html#Snowball.Client.list_clusters)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/snowball.html#Snowball.Client.list_clusters)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_snowball/client.html#list_clusters)
         """
 
@@ -341,7 +341,7 @@ class SnowballClient(BaseClient):
         (AMIs) that are owned by your AWS account that would be supported for use on a
         Snow device.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/snowball.html#Snowball.Client.list_compatible_images)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/snowball.html#Snowball.Client.list_compatible_images)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_snowball/client.html#list_compatible_images)
         """
 
@@ -349,7 +349,7 @@ class SnowballClient(BaseClient):
         """
         Returns an array of `JobListEntry` objects of the specified length.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/snowball.html#Snowball.Client.list_jobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/snowball.html#Snowball.Client.list_jobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_snowball/client.html#list_jobs)
         """
 
@@ -359,7 +359,7 @@ class SnowballClient(BaseClient):
         """
         Lists all long-term pricing types.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/snowball.html#Snowball.Client.list_long_term_pricing)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/snowball.html#Snowball.Client.list_long_term_pricing)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_snowball/client.html#list_long_term_pricing)
         """
 
@@ -380,7 +380,7 @@ class SnowballClient(BaseClient):
         While a cluster's `ClusterState` value is in the `AwaitingQuorum` state, you can
         update some of the information associated with a cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/snowball.html#Snowball.Client.update_cluster)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/snowball.html#Snowball.Client.update_cluster)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_snowball/client.html#update_cluster)
         """
 
@@ -402,7 +402,7 @@ class SnowballClient(BaseClient):
         While a job's `JobState` value is `New` , you can update some of the information
         associated with a job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/snowball.html#Snowball.Client.update_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/snowball.html#Snowball.Client.update_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_snowball/client.html#update_job)
         """
 
@@ -412,7 +412,7 @@ class SnowballClient(BaseClient):
         """
         Updates the state when a shipment state changes to a different state.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/snowball.html#Snowball.Client.update_job_shipment_state)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/snowball.html#Snowball.Client.update_job_shipment_state)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_snowball/client.html#update_job_shipment_state)
         """
 
@@ -426,7 +426,7 @@ class SnowballClient(BaseClient):
         """
         Updates the long-term pricing type.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/snowball.html#Snowball.Client.update_long_term_pricing)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/snowball.html#Snowball.Client.update_long_term_pricing)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_snowball/client.html#update_long_term_pricing)
         """
 
@@ -435,7 +435,7 @@ class SnowballClient(BaseClient):
         self, operation_name: Literal["describe_addresses"]
     ) -> DescribeAddressesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/snowball.html#Snowball.Paginator.DescribeAddresses)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/snowball.html#Snowball.Paginator.DescribeAddresses)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_snowball/paginators.html#describeaddressespaginator)
         """
 
@@ -444,14 +444,14 @@ class SnowballClient(BaseClient):
         self, operation_name: Literal["list_cluster_jobs"]
     ) -> ListClusterJobsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/snowball.html#Snowball.Paginator.ListClusterJobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/snowball.html#Snowball.Paginator.ListClusterJobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_snowball/paginators.html#listclusterjobspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_clusters"]) -> ListClustersPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/snowball.html#Snowball.Paginator.ListClusters)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/snowball.html#Snowball.Paginator.ListClusters)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_snowball/paginators.html#listclusterspaginator)
         """
 
@@ -460,13 +460,13 @@ class SnowballClient(BaseClient):
         self, operation_name: Literal["list_compatible_images"]
     ) -> ListCompatibleImagesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/snowball.html#Snowball.Paginator.ListCompatibleImages)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/snowball.html#Snowball.Paginator.ListCompatibleImages)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_snowball/paginators.html#listcompatibleimagespaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_jobs"]) -> ListJobsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/snowball.html#Snowball.Paginator.ListJobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/snowball.html#Snowball.Paginator.ListJobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_snowball/paginators.html#listjobspaginator)
         """
